# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

<!-- insertion marker -->
## [1.1.0](https://github.com/mkdocstrings/griffe-typing-deprecated/releases/tag/1.1.0) - 2024-12-10

<small>[Compare with 1.0.0](https://github.com/mkdocstrings/griffe-typing-deprecated/compare/1.0.0...1.1.0)</small>

### Features

- Add support for decorator from `typing_extensions` package ([7a5eb7c](https://github.com/mkdocstrings/griffe-typing-deprecated/commit/7a5eb7c1fe9a789861e68bb9b4b746065a09ab01) by Max). [PR-3](https://github.com/mkdocstrings/griffe-warnings-deprecated/pull/3)

### Bug Fixes

- Parse deprecation message from expression arguments ([0b5ffd3](https://github.com/mkdocstrings/griffe-typing-deprecated/commit/0b5ffd383d69f4df211663e2a2ed53108b7c0478) by Stefan Mejlgaard). [Issue-4](https://github.com/mkdocstrings/griffe-warnings-deprecated/issues/4), [PR-5](https://github.com/mkdocstrings/griffe-warnings-deprecated/pull/5), Co-authored-by: Timothée Mazzucotelli <dev@pawamoy.fr>

## [1.0.0](https://github.com/mkdocstrings/griffe-typing-deprecated/releases/tag/1.0.0) - 2024-10-12

<small>[Compare with first commit](https://github.com/mkdocstrings/griffe-typing-deprecated/compare/1dcbba53899c201f0ba1792f6b87978d5fb0d72f...1.0.0)</small>

### Features

- Make project public! ([6c7da38](https://github.com/mkdocstrings/griffe-typing-deprecated/commit/6c7da38581aeca6a93ff205c915afd0942584ab9) by Timothée Mazzucotelli).
